Modules
- amd
- Extensions tagged AMD
- amdx
- Extensions tagged AMDX
- android
- Extensions tagged ANDROID
- arm
- Extensions tagged ARM
- ext
- Extensions tagged EXT
- fuchsia
- Extensions tagged FUCHSIA
- ggp
- Extensions tagged GGP
- Extensions tagged GOOGLE
- huawei
- Extensions tagged HUAWEI
- img
- Extensions tagged IMG
- intel
- Extensions tagged INTEL
- khr
- Extensions tagged KHR
- lunarg
- Extensions tagged LUNARG
- msft
- Extensions tagged MSFT
- mvk
- Extensions tagged MVK
- nn
- Extensions tagged NN
- nv
- Extensions tagged NV
- nvx
- Extensions tagged NVX
- prelude
- qcom
- Extensions tagged QCOM
- qnx
- Extensions tagged QNX
- sec
- Extensions tagged SEC
- util
- valve
- Extensions tagged VALVE
- vk
- Raw Vulkan bindings and types, generated from
vk.xml
Macros
- define_
handle - handle_
nondispatchable - match_
in_ struct - Given an immutable raw pointer to a type with an
s_typemember such asvk::BaseInStructure, match on a set of Vulkan structures. The struct will be rebound to the given variable of the type of the given Vulkan structure. - match_
out_ struct - Given a mutable raw pointer to a type with an
s_typemember such asvk::BaseOutStructure, match on a set of Vulkan structures. The struct will be rebound to the given variable of the type of the given Vulkan structure. - vk_
bitflags_ wrapped
Structs
- Device
- https://registry.khronos.org/vulkan/specs/1.3-extensions/man/html/VkDevice.html
- Device
FnV1_ 0 - Raw Vulkan 1 device-level function pointers
- Device
FnV1_ 1 - Raw Vulkan 1.1 device-level function pointers
- Device
FnV1_ 2 - Raw Vulkan 1.2 device-level function pointers
- Device
FnV1_ 3 - Raw Vulkan 1.3 device-level function pointers
- Entry
- Holds the Vulkan functions independent of a particular instance
- Entry
FnV1_ 0 - Raw Vulkan 1 entry point function pointers
- Entry
FnV1_ 1 - Raw Vulkan 1.1 entry point function pointers
- Entry
FnV1_ 2 - Raw Vulkan 1.2 entry point function pointers
- Entry
FnV1_ 3 - Raw Vulkan 1.3 entry point function pointers
- Instance
- https://registry.khronos.org/vulkan/specs/1.3-extensions/man/html/VkInstance.html
- Instance
FnV1_ 0 - Raw Vulkan 1 instance-level function pointers
- Instance
FnV1_ 1 - Raw Vulkan 1.1 instance-level function pointers
- Instance
FnV1_ 2 - Raw Vulkan 1.2 instance-level function pointers
- Instance
FnV1_ 3 - Raw Vulkan 1.3 instance-level function pointers
- Static
Fn - Raw Vulkan 1 static function pointers